## $Id: pages.py 16508 2021-06-16 11:54:39Z henrik $
##
## Copyright (C) 2015 Uli Fouquet & Henrik Bettermann
## This program is free software; you can redistribute it and/or modify
## it under the terms of the GNU General Public License as published by
## the Free Software Foundation; either version 2 of the License, or
## (at your option) any later version.
##
## This program is distributed in the hope that it will be useful,
## but WITHOUT ANY WARRANTY; without even the implied warranty of
## MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
## GNU General Public License for more details.
##
## You should have received a copy of the GNU General Public License
## along with this program; if not, write to the Free Software
## Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA 02111-1307 USA
##
""" Viewing components for Kofa objects.
"""

import grok
from zope.component import getUtility
from waeup.kofa.interfaces import IKofaUtils
from waeup.kofa.browser.pages import (
    SessionConfigurationAddFormPage,
    SessionConfigurationManageFormPage,
    ConfigurationContainerManageFormPage,
    SourcesOverview)
from waeup.kofa.browser.layout import KofaPage
from kofacustom.nigeria.interfaces import (
    high_qual, high_grade, exam_types, LGASource,
    ICustomSessionConfiguration,
    ICustomSessionConfigurationAdd)
from kofacustom.nigeria.interfaces import MessageFactory as _

class NigeriaSourcesOverview(SourcesOverview):

    def _set_high_qual(self):
        vocab_terms = high_qual.by_value.values()
        self.high_qual = sorted([(x.token, x.title,) for x in vocab_terms])
        return

    def _set_high_grade(self):
        vocab_terms = high_grade.by_value.values()
        self.high_grade = sorted([(x.token, x.title,) for x in vocab_terms])
        return

    def _set_exam_types(self):
        vocab_terms = exam_types.by_value.values()
        self.exam_types = sorted([(x.token, x.title,) for x in vocab_terms])
        return

    def _set_lgas(self):
        lgasource = LGASource().factory
        self.lgas = []
        for key in lgasource.getValues():
            title = lgasource.getTitle(key)
            self.lgas.append((key, title))
        return

    def _set_grading_sys(self):
        grading_sys = getUtility(IKofaUtils).GRADING_SYSTEM_DICT
        self.grading_sys = sorted(grading_sys.items())
        return

    def update(self):
        super(NigeriaSourcesOverview, self).update()
        self._set_high_qual()
        self._set_high_grade()
        self._set_exam_types()
        self._set_lgas()
        self._set_grading_sys()
        return

class NigeriaSourcesOverviewPage(KofaPage, NigeriaSourcesOverview):
    grok.name('sources')
    grok.require('waeup.Public')
    label = _(u'Sources & Vocabularies')
    pnav = 0

class CustomSessionConfigurationAddFormPage(SessionConfigurationAddFormPage):
    """Add a session configuration object to configuration container.
    """
    form_fields = grok.AutoFields(ICustomSessionConfigurationAdd)

class CustomSessionConfigurationManageFormPage(
    SessionConfigurationManageFormPage):
    """Manage session configuration object.
    """
    form_fields = grok.AutoFields(ICustomSessionConfiguration)